@@ -33,15 +33,6 @@ class Boiler(Block):
         self.add_connection(new_conn_input_flow, is_input=True, append_to_support_block=0)
         self.add_connection(new_conn_output_flow, is_input=False, append_to_support_block=0)
 
-    def export_xml_other_parameters(self) -> ETree.Element:
-
-        other_tree = ETree.Element("Other")
-        return other_tree
-
-    def append_xml_other_parameters(self, input_list: ETree.Element):
-
-        pass
-
     def export_xml_connection_list(self) -> ETree.Element:
 
         xml_connection_list = ETree.Element("Connections")
